pingus-cvs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Pingus-CVS] CVS: Games/Pingus/src/editor editor.cxx, 1.52, 1.53 editor_


From: torangan
Subject: [Pingus-CVS] CVS: Games/Pingus/src/editor editor.cxx, 1.52, 1.53 editor_event.cxx, 1.60, 1.61 editor_help_screen.cxx, 1.12, 1.13 generic_property_frame.cxx, 1.6, 1.7
Date: 19 Aug 2003 19:56:57 -0000

Update of /var/lib/cvs/Games/Pingus/src/editor
In directory dark:/tmp/cvs-serv24211/editor

Modified Files:
        editor.cxx editor_event.cxx editor_help_screen.cxx 
        generic_property_frame.cxx 
Log Message:
changes to cope with new level endings


Index: editor.cxx
===================================================================
RCS file: /var/lib/cvs/Games/Pingus/src/editor/editor.cxx,v
retrieving revision 1.52
retrieving revision 1.53
diff -u -d -r1.52 -r1.53
--- editor.cxx  22 Apr 2003 16:40:41 -0000      1.52
+++ editor.cxx  19 Aug 2003 19:56:55 -0000      1.53
@@ -346,7 +346,7 @@
 
   StatManager::instance()->set_int("next-backup-id", backup_id + 1);
 
-  std::string filename = System::get_backupdir () + "pingus-backup-" + 
to_string(backup_id) + ".xml";
+  std::string filename = System::get_backupdir () + "pingus-backup-" + 
to_string(backup_id) + ".plf";
   std::cout << "Editor: saving backup level to: " << filename << std::endl;
   object_manager->save_level_xml(filename.c_str());
   return filename;

Index: editor_help_screen.cxx
===================================================================
RCS file: /var/lib/cvs/Games/Pingus/src/editor/editor_help_screen.cxx,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -d -r1.12 -r1.13
--- editor_help_screen.cxx      24 Apr 2003 15:18:19 -0000      1.12
+++ editor_help_screen.cxx      19 Aug 2003 19:56:55 -0000      1.13
@@ -81,7 +81,7 @@
 
   x_pos = 64;
   y_pos = 500;
-  font->print_left (x_pos, y_pos + 0, _("Naming Convention: 
<LEVELNAME><NUMBER>-<CREATOR>.xml"));
+  font->print_left (x_pos, y_pos + 0, _("Naming Convention: 
<LEVELNAME><NUMBER>-<CREATOR>.plf"));
 
   font->print_left (x_pos, y_pos + 30, _("When you have created a level and 
want to have it in the next Pingus release,\n"
                                         "please mail it to address@hidden"));

Index: generic_property_frame.cxx
===================================================================
RCS file: /var/lib/cvs/Games/Pingus/src/editor/generic_property_frame.cxx,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- generic_property_frame.cxx  19 Apr 2003 10:23:18 -0000      1.6
+++ generic_property_frame.cxx  19 Aug 2003 19:56:55 -0000      1.7
@@ -17,7 +17,6 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-#include <iostream>
 #include <assert.h>
 #include <ClanLib/GUI/label.h>
 #include <ClanLib/GUI/inputbox.h>





reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: editor_event.cxx
===================================================================
RCS file: /var/lib/cvs/Games/Pingus/src/editor/editor_event.cxx,v
retrieving revision 1.60
retrieving revision 1.61
diff -u -d -r1.60 -r1.61
--- editor_event.cxx    16 Aug 2003 20:51:28 -0000      1.60
+++ editor_event.cxx    19 Aug 2003 19:56:55 -0000      1.61
@@ -580,7 +580,7 @@
   StringReader reader(_("Enter filename to save as:"), editor->last_level);
 
   // FIXME: The pattern '*' will not work on windows, we should use
   // FIXME: *.xml or better switch to CL_DirectoryScanner
   dir = System::opendir(System::get_statdir() + "levels/", "*");
 
   for (System::Directory::iterator i = dir.begin(); i != dir.end(); ++i)
@@ -599,10 +599,10 @@
 
   if (!str.empty())
     {
-      if (str.substr(str.size() - 4) ==  ".xml")
+      if (str.substr(str.size() - 4) ==  ".plf")
        object_manager->save_level_xml(str);
       else
-       object_manager->save_level_xml(str + ".xml");
+       object_manager->save_level_xml(str + ".plf");
 
       editor->last_level = str;
     }
@@ -580,7 +580,7 @@
 
   // FIXME: The pattern '*' will not work on windows, we should use
-  // FIXME: *.xml or better switch to CL_DirectoryScanner
+  // FIXME: *.plf or better switch to CL_DirectoryScanner
   dir = System::opendir(System::get_statdir() + "levels/", "*");
 
